    .. _upnp_services_clients_av_transport_client:

coherence.upnp.services.clients.av\_transport\_client (module)
--------------------------------------------------------------

.. automodule:: coherence.upnp.services.clients.av_transport_client
